mathtools.NonreducedFraction
============================

.. inheritance-diagram:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction
   :private-bases:

.. autoclass:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.denominator

.. autoattribute:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.imag

    Inherited from :py:class:`numbers.Real`

.. autoattribute:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.numerator

.. autoattribute:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.pair

.. autoattribute:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.real

    Inherited from :py:class:`numbers.Real`

.. autoattribute:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.conjugate

    Inherited from :py:class:`numbers.Real`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.from_decimal

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.from_float

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.limit_denominator

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.reduce

Special Methods
---------------

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__abs__

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__add__

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__complex__

    Inherited from :py:class:`numbers.Real`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__div__

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__divmod__

    Inherited from :py:class:`numbers.Real`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__eq__

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__float__

    Inherited from :py:class:`numbers.Rational`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__floordiv__

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__ge__

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__gt__

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__hash__

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__le__

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__lt__

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__mod__

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__mul__

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__ne__

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__neg__

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__nonzero__

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__pos__

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__pow__

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__radd__

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__rdiv__

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__rdivmod__

    Inherited from :py:class:`numbers.Real`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__rfloordiv__

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__rmod__

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__rmul__

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__rpow__

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__rsub__

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__rtruediv__

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__str__

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__sub__

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__truediv__

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__trunc__

    Inherited from :py:class:`fractions.Fraction`
